# Supports Organizer.rb
=begin rdoc
= Select Same Length Lines
Copyright 2009, Chris Fullmer
All Rights Reserved

== Disclaimer
THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.

== License
This software is distributed under the Smustard End User License Agreement
http://www.smustard.com/eula

== Information
Author:: Chris Fullmer
Organization:: www.ChrisFullmer.com and distributed on www.sketchucation.com
Name:: Select Same Length Lines
Version:: v1.1
SU Version:: Developed on SU 7, should be compatible with 6 and 5 at least.
Date:: March 09, 2009
Description:: This script selects all edges (lines) of a desired length.
Usage:: If you have a line selected when you run this script, it will select all lines of that same length.  If no line is selected, it will prompt you for a line length.
History::
1.0:: 2009-02-22
   * First release
1.1:: 2009-03-09
   * Organizer.rb support. If you place this script into an organizer directory, it will appear in the correct submenu.  If its just in the plugins folder, it will appear in "Chris Fullmer Tools" submenu of the Plugins Menu."
=end

require 'sketchup.rb'

module Clf_same_length_selection

def Clf_same_length_selection.line_length( line )
	distance = ""
	a = line.start.position
	b = line.end.position
	dx = a.x-b.x 
	dy = a.y-b.y 
	dz = a.z-b.z 
	distance = (dx*dx + dy*dy + dz*dz) ** 0.5
	distance.to_l
end # line_length

def Clf_same_length_selection.main
model = Sketchup.active_model
selection = model.selection
prompts = []
values = []
count = 0
edges_array = []

if selection.length == 1
	if selection[0].typename != "Edge"
		selection.clear
	else
		sel_len = Clf_same_length_selection.line_length selection[0]
	end
else
	selection.clear
end

if selection.length < 1
	prompts = ["Line length to select:   "]
	values = []
	results = UI.inputbox prompts, values
	sel_len = results[0].to_l
end

selection = model.active_entities

selection.to_a.each do |e|
	if e.typename == "Edge"
		e_len = Clf_same_length_selection.line_length e
		if e_len == sel_len
			edges_array.push e
		end
	end
	count = count + 1
end

selection = model.selection
selection.clear
selection.add edges_array
end
end

if( $submenu )
	organizer = $submenu 
	if !file_loaded?(__FILE__) then
		organizer.add_item("Select Lines by Length") { Clf_same_length_selection.main  }
	end
else
	if !file_loaded?('clf_menu_loader') then
		$clf_tools_menu = UI.menu("Plugins").add_submenu("Chris Fullmer Tools")
	end
	if !file_loaded?(__FILE__) then
		$clf_tools_menu.add_item("Select Lines by Length") { Clf_same_length_selection.main  }
	end
end

file_loaded('clf_menu_loader')
file_loaded(__FILE__)